==> suite3270-4.2ga6-src.tgz: suite3270-4.2/tcl3270/Test/testQuit.py <==
#!/usr/bin/env python3
#
# Copyright (c) 2021-2022 Paul Mattes.
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the names of Paul Mattes nor the names of his contributors
#       may be used to endorse or promote products derived from this software
#       without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY PAUL MATTES "AS IS" AND ANY EXPRESS OR IMPLIED
# WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
# EVENT SHALL PAUL MATTES BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
# WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
# OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
# ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
# tcl3270 Quit test

import unittest
from subprocess import Popen, PIPE, DEVNULL
import sys
import Common.Test.cti as cti

@unittest.skipIf(sys.platform == "darwin", "macOS does not like tcl")
class TestTcl3270Quit(cti.cti):

    # tcl3270 3270 quit test
    def test_tcl3270_quit(self):

        # Start tcl3270.
        tcl3270 = Popen(cti.vgwrap(["tcl3270", "tcl3270/Test/quit.tcl"]),
            stdin=DEVNULL, stdout=DEVNULL, stderr=DEVNULL)
        self.children.append(tcl3270)

        # Wait for the process to exit.
        self.vgwait(tcl3270)

if __name__ == '__main__':
    unittest.main()

==> suite3270-4.4ga6-src.tgz: suite3270-4.4/tcl3270/Test/testQuit.py <==
#!/usr/bin/env python3
#
# Copyright (c) 2021-2025 Paul Mattes.
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the names of Paul Mattes nor the names of his contributors
#       may be used to endorse or promote products derived from this software
#       without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY PAUL MATTES "AS IS" AND ANY EXPRESS OR IMPLIED
# WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
# EVENT SHALL PAUL MATTES BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
# WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
# OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
# ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
# tcl3270 Quit test

from subprocess import Popen, DEVNULL
import sys
import unittest

from Common.Test.cti import *

@unittest.skipIf(sys.platform == "darwin", "macOS does not like tcl")
class TestTcl3270Quit(cti):

    # tcl3270 3270 quit test
    def test_tcl3270_quit(self):

        # Start tcl3270.
        tcl3270 = Popen(vgwrap(["tcl3270", "tcl3270/Test/quit.tcl"]),
            stdin=DEVNULL, stdout=DEVNULL, stderr=DEVNULL)
        self.children.append(tcl3270)

        # Wait for the process to exit.
        self.vgwait(tcl3270)

if __name__ == '__main__':
    unittest.main()
